/*******************************************************************************
* File Name: Pot.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Pot.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        Pot_PC =   (Pot_PC & \
                                (uint32)(~(uint32)(Pot_DRIVE_MODE_IND_MASK << (Pot_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (Pot_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: Pot_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Pot_Write(uint8 value) 
{
    uint8 drVal = (uint8)(Pot_DR & (uint8)(~Pot_MASK));
    drVal = (drVal | ((uint8)(value << Pot_SHIFT) & Pot_MASK));
    Pot_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: Pot_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Pot_DM_STRONG     Strong Drive 
*  Pot_DM_OD_HI      Open Drain, Drives High 
*  Pot_DM_OD_LO      Open Drain, Drives Low 
*  Pot_DM_RES_UP     Resistive Pull Up 
*  Pot_DM_RES_DWN    Resistive Pull Down 
*  Pot_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Pot_DM_DIG_HIZ    High Impedance Digital 
*  Pot_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Pot_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(Pot__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: Pot_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Pot_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Pot_Read(void) 
{
    return (uint8)((Pot_PS & Pot_MASK) >> Pot_SHIFT);
}


/*******************************************************************************
* Function Name: Pot_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Pot_ReadDataReg(void) 
{
    return (uint8)((Pot_DR & Pot_MASK) >> Pot_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Pot_INTSTAT) 

    /*******************************************************************************
    * Function Name: Pot_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Pot_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(Pot_INTSTAT & Pot_MASK);
		Pot_INTSTAT = maskedStatus;
        return maskedStatus >> Pot_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
